pub struct Span {
pub offset: usize,
pub len: usize,
pub line: u32,
pub col: u32,
}Expand description
Location of a parser error in the original source buffer.
Fields
offset: usizeByte offset from the start of the input (0-based).
len: usizeLength of the offending substring, in bytes.
line: u321-based line number where the error starts.
col: u321-based column number where the error starts.
Implementations