runtime_gate

Function runtime_gate 

pub fn runtime_gate() -> Result<RuntimeGate, FfiError>
Returns the active runtime gate if the pool is initialized.

FFI entry points use this to refuse work rather than implicitly start the runtime.

Errors

Returns FfiError::RuntimeUninitialized if ensure_runtime has not been called yet on this process.